@@ -2,6 +2,6 @@ import yaml
 
 
 def get_password():
-    variables = yaml.load(open(
+    variables = yaml.safe_load(open(
         'inventory/group_vars/gitlab/gitlab.yml'))
     return variables['gitlab_password']
