@@ -1,7 +1,7 @@
 import json
 
 from enough import settings
-from enough.common import ansible_utils, retry
+from enough.common import ansible_utils
 
 testinfra_hosts = ['ansible://cloud-host']
 
@@ -19,25 +19,6 @@ def test_nextcloud(host):
     assert 0 == cmd.rc
 
 
-def test_nextcloud_via_tor(host):
-    with host.sudo():
-        host.run("apt-get install -y curl")
-
-    @retry.retry(AssertionError, tries=5)
-    def run():
-        cmd = host.run("""
-        set -xe
-        hostname=$(sudo cat /var/lib/tor/services/cloud/hostname)
-        torsocks curl --silent http://$hostname/login |
-           grep --quiet 'This application requires JavaScript'
-        """)
-        print(cmd.stdout)
-        print(cmd.stderr)
-        assert 0 == cmd.rc
-
-    run()
-
-
 def test_nextcloud_apps(host, pytestconfig):
     cmd = host.run("""
         set -xe
