@@ -34,3 +34,18 @@ def test_that_retry_works_on_complex_function():
     c = C()
     assert c.f()
     assert c.fail == 0
+
+
+def test_that_retry_works_with_fixed_delays():
+    class C():
+        fail = 2
+
+        @retry.retry(Exception, tries=3, delay=2, exponential=False)
+        def f(self):
+            self.fail -= 1
+            assert self.fail == 0
+            return True
+
+    c = C()
+    assert c.f()
+    assert c.fail == 0
